
def end():
    while True:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                sys.exit()
        clock.tick(60)
#start_script.start() fdgdshggfdhjkhsifdajgiudshjfguhdfbshui end_script.end()